Bài giảng

1. Định nghĩa & vai trò của các khái niệm chuyên môn trong đề bài
2. Khung lý thuyết/mô hình & xu hướng nghiên cứu đến nay
3. Phương pháp ứng dụng cụ thể trong thực tế (quy trình, mục tiêu và hướng dẫn kỹ thuật)
4. Phân tích case study trong nước và thế giới (phân tích case study thế giới về thực trạng, vấn đề và phương pháp, từ đó ứng dụng thực hành phân tích case study trong nước)
